@@ -11,9 +11,12 @@ use v_api::v_onto::onto_index::OntoIndex;
 use v_storage::storage::VStorage;
 #[cfg(feature = "extended-siginfo")]
 type Signals = signal_hook::iterator::SignalsInfo<signal_hook::iterator::exfiltrator::origin::WithOrigin>;
+use chrono::Utc;
 #[cfg(not(feature = "extended-siginfo"))]
 use signal_hook::iterator::Signals;
 use signal_hook::low_level;
+use v_queue::consumer::Consumer;
+use v_queue::record::Mode;
 
 pub const DATA_BASE_PATH: &str = "./data";
 
@@ -69,3 +72,25 @@ pub fn sys_sig_listener() -> Result<Receiver<i32>, Error> {
 
     Ok(receiver)
 }
+
+const MAIN_QUEUE_NAME: &str = "individuals-flow";
+
+pub fn get_queue_status(id: &str) -> Individual {
+    let mut out_indv = Individual::default();
+    if let Some(consumer_name) = id.strip_prefix("srv:queue-state-") {
+        let base_path: &str = &(DATA_BASE_PATH.to_owned() + "/queue");
+        if let Ok(mut c) = Consumer::new_with_mode(base_path, consumer_name, MAIN_QUEUE_NAME, Mode::Read) {
+            c.open(false);
+            c.get_info();
+            if c.queue.get_info_of_part(c.id, false).is_ok() {
+                out_indv.set_id(id);
+                out_indv.add_uri("rdf:type", "v-s:AppInfo");
+                out_indv.add_datetime("v-s:created", Utc::now().naive_utc().timestamp());
+                out_indv.add_uri("srv:queue", &("srv:".to_owned() + consumer_name));
+                out_indv.add_integer("srv:total_count", c.queue.count_pushed as i64);
+                out_indv.add_integer("srv:current_count", c.count_popped as i64);
+            }
+        }
+    }
+    out_indv
+}
